@@ -1,9 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * linux-cdrom.c: Linux CD controlling functions.
+ *  Authors: Iain Holmes <iain@ximian.com>
+ *
+ *  Copyright 2001 Iain Holmes
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * Copyright (C) 2001 Iain Holmes
- * Authors: Iain Holmes  <iain@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -865,7 +879,7 @@ linux_cdrom_get_status (GnomeCDRom *cdrom,
 				g_print ("Error reading CD header");
 				linux_cdrom_close (lcd);
 
-				return;
+				return FALSE;
 			}
 			realstatus->cd = GNOME_CDROM_STATUS_DATA_CD;
 
@@ -1098,7 +1112,7 @@ linux_cdrom_get_cddb_data (GnomeCDRom *cdrom,
 
 	if (priv->track_info == NULL) {
 		*data = NULL;
-		return TRUE;
+		return FALSE;
 	}
 	
 	*data = g_new0 (GnomeCDRomCDDBData, 1);
